package com.vieaura.camera_plugin.vieaura_camera_plugin

import androidx.annotation.NonNull
import android.Manifest
import android.app.Activity
import android.content.Intent
import android.content.pm.PackageManager
import android.os.Bundle
import androidx.core.content.ContextCompat
import androidx.core.app.ActivityCompat

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import com.vieaura.camera_plugin.vieaura_camera_plugin.MainActivity
import com.vieaura.camera_plugin.vieaura_camera_plugin.RealwearActivity


/** VieauraCameraPlugin */
class VieauraCameraPlugin: FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  lateinit var activity: Activity

  companion object {
    private const val CHANNEL = "vieaura_camera_plugin"
    private lateinit var methodResult: Result

    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), CHANNEL)
      val plugin = VieauraCameraPlugin()

      plugin.activity = (registrar.activity())!!
      channel.setMethodCallHandler(plugin)
    }

    @JvmStatic
    fun onTakePhotosResults(result: ArrayList<String>) {
      if (result != null) {
        methodResult.success(result)
      } else {
        methodResult.error(VieauraCameraPlugin::class.java.canonicalName, "Unable to Take Photo", null)
      }
    }

    @JvmStatic
    fun onEmptyResult() {
      methodResult.success(null)
    }
  }

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, CHANNEL)
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "takePhotosOnAndroidPhone") {
      methodResult = result
      val intent = Intent(activity, MainActivity::class.java)
      activity.startActivity(intent)
    } else if (call.method == "takePhotosOnRealwear") {
      methodResult = result
      val intent = Intent(activity, RealwearActivity::class.java)
      activity.startActivity(intent)
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    this.activity = binding.activity
  }

  override fun onDetachedFromActivity() {
  }

  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
  }
}
